==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceDataProviderSchemaChangedEventArgsDescription } from "./DataSourceDataProviderSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, _super);
    function DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b(a);
        a.u("DataSourceDataProviderSchemaChangedEventArgs", function () { return new DataSourceDataProviderSchemaChangedEventArgsDescription(); });
        a.t("DataSourceDataProviderSchemaChangedEventArgs", DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.$t = markType(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, 'DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata');
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceDataProviderSchemaChangedEventArgsDescription } from "./DataSourceDataProviderSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, _super);
    function DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b(a);
        a.aa("DataSourceDataProviderSchemaChangedEventArgs", function () { return new DataSourceDataProviderSchemaChangedEventArgsDescription(); });
        a.z("DataSourceDataProviderSchemaChangedEventArgs", DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.$t = markType(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, 'DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata');
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata };
